@@ -1,4 +1,4 @@
-import os
+import os,sys
 import logging
 import boto3
 from pathlib import Path
@@ -7,29 +7,40 @@ import glob
 import pandas as pd
 from pythonjsonlogger.jsonlogger import JsonFormatter
 import boto3
-
 from dotenv import load_dotenv
 
-from SharedData.SharedDataAWSKinesis import KinesisStreamHandler
+from SharedData.SharedDataAWSKinesis import KinesisLogStreamHandler
+
+
+load_dotenv()  # take environment variables from .env.
+
+if not 'DATABASE_FOLDER' in os.environ:    
+    os.environ['DATABASE_FOLDER'] = os.path.expanduser("~")+'\DB' 
+
+if not 'S3_BUCKET' in os.environ:    
+    os.environ['S3_BUCKET'] = 's3://deepportfolio'
+
+if not 'LOG_STREAMNAME' in os.environ:    
+    os.environ['LOG_STREAMNAME'] = 'deepportfolio-logs'
+
+if not 'LOG_PROFILENAME' in os.environ:    
+    os.environ['LOG_PROFILENAME'] = 'kinesis-logs-write-only'
+
 
 class Logger:
 
     log = None
-    DATABASE_FOLDER = os.path.expanduser("~")+'\DB'
 
     def __init__(self, source):
-        self.source = source
-
-        load_dotenv()  # take environment variables from .env.
-        
+        os.environ['PATH'] = os.environ['PATH']+';'+';'.join(sys.path)
+                
         if 'SOURCE_FOLDER' in os.environ:
             commompath = os.path.commonpath([source,os.environ['SOURCE_FOLDER']])
             source = source.replace(commompath,'')
+
         source = source.lstrip('\\').lstrip('/')
         source = source.replace('.py','')
-
-        if not 'DATABASE_FOLDER' in os.environ:
-            os.environ['DATABASE_FOLDER'] = Logger.DATABASE_FOLDER
+        self.source = source
 
         path = Path(os.environ['DATABASE_FOLDER'])
         path = path / 'Logs'
@@ -65,7 +76,7 @@ class Logger:
         fhandler.setFormatter(formatter)
         self.log.addHandler(fhandler)
         #log to aws kinesis
-        kinesishandler = KinesisStreamHandler()
+        kinesishandler = KinesisLogStreamHandler()
         kinesishandler.setLevel(logging.DEBUG)
         jsonformatter = JsonFormatter(os.environ['USERNAME']+'@'+os.environ['USERDOMAIN'] + 
             ';%(asctime)s;%(name)s;%(levelname)s;%(message)s',\
@@ -85,11 +96,12 @@ class Logger:
         for f in files:
             source = f[lenlogsdir+1:].replace('.log','.py')
             try:
-                _df = pd.read_csv(f,header=None,sep=';')
+                _df = pd.read_csv(f,header=None,sep=';',\
+                    error_bad_lines=False,engine='python')
                 _df.columns = ['user','datetime','name','type','message']
                 _df['source'] = source
                 df = df.append(_df)
             except Exception as e:
-                print(e)
-                pass
+                print('Read logs error:'+str(e))
+
         return df
