@@ -18,15 +18,18 @@ class Metadata():
 
         Logger.log.debug('Initializing Metadata %s,%s' % (name,mode))
 
-        if mode == 'local':
-            self.s3read = False
-            self.s3write = False
-        elif mode == 'r':
+        
+        self.s3read = False
+        self.s3write = False
+        if mode == 'r':
             self.s3read = True
             self.s3write = False
         elif mode == 'rw':
             self.s3read = True
             self.s3write = True
+        elif mode == 'w':
+            self.s3read = False
+            self.s3write = True
         
 
         self.name = name
