@@ -17,16 +17,18 @@ class SharedData:
         
         self.database = database
         self.sync_frequency_days = sync_frequency_days
-
-        if mode == 'local':
-            self.s3read = False
-            self.s3write = False
-        elif mode == 'r':
+        
+        self.s3read = False
+        self.s3write = False
+        if mode == 'r':
             self.s3read = True
             self.s3write = False
         elif mode == 'rw':
             self.s3read = True
             self.s3write = True
+        elif mode == 'w':
+            self.s3read = False
+            self.s3write = True
         
         # last download sync datetime
         self.lastsync = pd.DataFrame([])
