@@ -1,4 +1,4 @@
-import os
+import os,sys
 import logging
 import subprocess
 import boto3
@@ -11,18 +11,16 @@ import pytz
 
 from SharedData.Logger import Logger
 
-S3_BUCKET='s3://deepportfolio'
-if not 'S3_BUCKET' in os.environ:
-    os.environ['S3_BUCKET'] = S3_BUCKET
-
 def S3SyncDownloadDataFrame(path,shm_name):
-    Logger.log.debug('AWS S3 Sync DataFrame %s...' % (shm_name))
+    Logger.log.debug('AWS S3 Sync DataFrame %s...' % (shm_name))    
 
     awsfolder = os.environ['S3_BUCKET']+'/'
     awsfolder = awsfolder+str(Path(shm_name).parents[0])
     awsfolder = awsfolder.replace('\\','/')+'/'   
     dbfolder = str(path)
     dbfolder = dbfolder.replace('\\','/')+'/'
+    env = os.environ.copy()
+    env['PATH'] = sys.exec_prefix+r'\Scripts'
 
     process = subprocess.Popen(['aws','s3','sync',awsfolder,dbfolder,\
         '--profile','s3readonly',\
@@ -30,7 +28,7 @@ def S3SyncDownloadDataFrame(path,shm_name):
         '--include',shm_name.split('/')[-1]+'.json',\
         '--include',shm_name.split('/')[-1]+'.npy'],\
         stdout=subprocess.PIPE, stderr=subprocess.PIPE,\
-        universal_newlines=True, shell=True)        
+        universal_newlines=True, shell=True, env=env)        
     
     while True:
         output = process.stdout.readline()
@@ -51,12 +49,15 @@ def S3SyncDownloadDataFrame(path,shm_name):
 def S3SyncDownloadTimeSeries(path,shm_name):    
     Logger.log.debug('AWS S3 sync download timeseries %s...' % (shm_name))           
     awsfolder = os.environ['S3_BUCKET']+'/'+shm_name+'/' 
+    env = os.environ.copy()
+    env['PATH'] = sys.exec_prefix+r'\Scripts'
+
     process = subprocess.Popen(['aws','s3','sync',awsfolder,path,\
         '--profile','s3readonly',\
         #'--delete',\
         '--exclude=shm_info.json'],\
         stdout=subprocess.PIPE, stderr=subprocess.PIPE,\
-        universal_newlines=True, shell=True)
+        universal_newlines=True, shell=True,env=env)
     
     while True:
         output = process.stdout.readline()
@@ -79,10 +80,14 @@ def S3SyncDownloadMetadata(pathpkl,name):
     Logger.log.debug('AWS S3 Sync metadata %s...' % (name))
     folder=str(pathpkl.parents[0]).replace(\
         os.environ['DATABASE_FOLDER'],'')
+    
     folder = folder.replace('\\','/')+'/'
     dbfolder = str(pathpkl.parents[0])
     dbfolder = dbfolder.replace('\\','/')+'/'
-    awsfolder = os.environ['S3_BUCKET'] + folder
+    awsfolder = os.environ['S3_BUCKET'] + folder    
+    env = os.environ.copy()
+    env['PATH'] = sys.exec_prefix+r'\Scripts'
+
     process = subprocess.Popen(['aws','s3','sync',awsfolder,dbfolder,\
         '--profile','s3readonly',\
         '--exclude','*',\
@@ -92,7 +97,7 @@ def S3SyncDownloadMetadata(pathpkl,name):
         '--include',name.split('/')[-1]+'.xlsx'],\
         #'--delete'],\
         stdout=subprocess.PIPE, stderr=subprocess.PIPE,\
-        universal_newlines=True, shell=True)        
+        universal_newlines=True, shell=True,env=env)        
     
     while True:
         output = process.stdout.readline()
@@ -108,10 +113,9 @@ def S3SyncDownloadMetadata(pathpkl,name):
         Logger.log.debug('AWS S3 Sync metadata %s DONE!' % (name))
     else:
         Logger.log.error('AWS S3 Sync metadata %s ERROR!' % (name))
+        Logger.log.error('AWS S3 Sync metadata \"%s\"' % (''.join(process.stderr.readlines())))
     return success
 
-
-
 def S3Upload(localfilepath):
     Logger.log.debug('Uploading to S3 '+str(localfilepath)+' ...')
     try:        
